@@ -510,31 +510,35 @@ class GitLabFormCore(object):
     @if_in_config_and_not_skipped
     def process_branches(self, project_and_group, configuration):
         for branch in sorted(configuration['branches']):
-            try:
-                if 'protected' in configuration['branches'][branch] and configuration['branches'][branch]['protected']:
-                    if ('developers_can_push' and 'developers_can_merge') in configuration['branches'][branch]:
-                        logging.debug("Setting branch '%s' as *protected*", branch)
-                        # unprotect first to reset 'allowed to merge' and 'allowed to push' fields
-                        self.gl.unprotect_branch_new_api(project_and_group, branch)
-                        self.gl.protect_branch(project_and_group, branch,
-                                               configuration['branches'][branch]['developers_can_push'],
-                                               configuration['branches'][branch]['developers_can_merge'])
-                    elif ('push_access_level' and 'merge_access_level' and 'unprotect_access_level') in configuration['branches'][branch]:
-                        logging.debug("Setting branch '%s' access level", branch)
-                        # unprotect first to reset 'allowed to merge' and 'allowed to push' fields
-                        self.gl.unprotect_branch_new_api(project_and_group, branch)
-                        self.gl.branch_access_level(project_and_group, branch,
-                                                    configuration['branches'][branch]['push_access_level'],
-                                                    configuration['branches'][branch]['merge_access_level'],
-                                                    configuration['branches'][branch]['unprotect_access_level'])
-                else:
-                    logging.debug("Setting branch '%s' as unprotected", branch)
+            self._protect_branch(project_and_group, configuration, branch)
+
+    def _protect_branch(self, project_and_group, configuration, branch):
+        try:
+            if 'protected' in configuration['branches'][branch] and configuration['branches'][branch]['protected']:
+                if ('developers_can_push' and 'developers_can_merge') in configuration['branches'][branch]:
+                    logging.debug("Setting branch '%s' as *protected*", branch)
+                    # unprotect first to reset 'allowed to merge' and 'allowed to push' fields
                     self.gl.unprotect_branch_new_api(project_and_group, branch)
-            except NotFoundException:
-                logging.warning("! Branch '%s' not found when trying to set it as protected/unprotected",
-                                branch)
-                if self.strict:
-                    exit(3)
+                    self.gl.protect_branch(project_and_group, branch,
+                                           configuration['branches'][branch]['developers_can_push'],
+                                           configuration['branches'][branch]['developers_can_merge'])
+                elif ('push_access_level' and 'merge_access_level' and 'unprotect_access_level') in \
+                        configuration['branches'][branch]:
+                    logging.debug("Setting branch '%s' access level", branch)
+                    # unprotect first to reset 'allowed to merge' and 'allowed to push' fields
+                    self.gl.unprotect_branch_new_api(project_and_group, branch)
+                    self.gl.branch_access_level(project_and_group, branch,
+                                                configuration['branches'][branch]['push_access_level'],
+                                                configuration['branches'][branch]['merge_access_level'],
+                                                configuration['branches'][branch]['unprotect_access_level'])
+            else:
+                logging.debug("Setting branch '%s' as unprotected", branch)
+                self.gl.unprotect_branch_new_api(project_and_group, branch)
+        except NotFoundException:
+            logging.warning("! Branch '%s' not found when trying to set it as protected/unprotected",
+                            branch)
+            if self.strict:
+                exit(3)
 
     @if_in_config_and_not_skipped
     def process_tags(self, project_and_group, configuration):
@@ -675,10 +679,7 @@ class GitLabFormCore(object):
                 # protect branch back after above operations
                 if configuration.get('branches|' + branch + '|protected'):
                     logging.debug("> Protecting the branch again.")
-                    self.gl.protect_branch(project_and_group, branch,
-                                           configuration['branches'][branch]['developers_can_push'],
-                                           configuration['branches'][branch]['developers_can_merge'])
-
+                    self._protect_branch(project_and_group, configuration, branch)
                 if configuration.get('files|' + file + '|only_first_branch'):
                     logging.info('Skipping other branches for this file, as configured.')
                     break
